@@ -1,9 +1,8 @@
 getnbparstats <- function(stat.indices = NULL) {
     
-    if (getRversion() < "3.1.0") dontCheck <- identity
     
     tmp <- names(getDLLRegisteredRoutines("PoweR")[[".C"]])
-    ind.stats <- as.numeric(sub("stat", "", tmp[grep("stat", tmp)]))
+    ind.stats <- as.numeric(sub("stat", "", tmp[grep("stat[1-9]", tmp)]))
     if (!all(stat.indices %in% ind.stats)) stop(paste("The values", paste(stat.indices[which(!(stat.indices %in% ind.stats))], collapse = " "),
                                                       " in 'stat.indices' do not correspond to any defined statistic!", collapse = ""))
     
@@ -15,7 +14,11 @@ getnbparstats <- function(stat.indices = NULL) {
   for (i in 1:lst) {
         Cstat.name <- "tmp" # To remove a NOTE at R CMD check
         Cstat.name <- paste("stat", stat.indices[i], sep = "")
-        nbparstats.list[i] <- (.C(dontCheck(Cstat.name), 0.0, 1L, 0.0, 1L, rep(" ", 50), 1L, 0.0, 0L,
+        #statsym <- getNativeSymbolInfo(Cstat.name, PACKAGE = "PoweR")
+mydotC <- get(".PoweR_stat_dispatch", envir = asNamespace("PoweR"))[[Cstat.name]]; if (is.null(mydotC)) stop("Unknown stat function: ", Cstat.name)
+
+        nbparstats.list[i] <- (#.C(statsym, 
+        mydotC(0.0, 1L, 0.0, 1L, rep(" ", 50), 1L, 0.0, 0L,
                                   0.0, 0.0, 0.0, 0L, 0L, 0L, 0.0, nbparamstat = 0L, PACKAGE = "PoweR"))$nbparamstat
     }
     
