@@ -6,9 +6,9 @@ help.law <- function(law.index) {
   
     if (!(law.index %in% 1:nb.laws)) stop(paste("Law index should be an integer between 1 and ", nb.laws, ".", sep = ""))
   
-    if (nchar(law.index) == 1) Rd <- paste("law000", law.index, sep = "")
-    if (nchar(law.index) == 2) Rd <- paste("law00", law.index, sep = "")
-    if (nchar(law.index) == 3) Rd <- paste("law0", law.index, sep = "")
+    if (nchar(law.index) == 1) Rd <- paste0("law000", law.index)
+    if (nchar(law.index) == 2) Rd <- paste0("law00", law.index)
+    if (nchar(law.index) == 3) Rd <- paste0("law0", law.index)
     
     help(Rd)
     
