@@ -1,11 +1,14 @@
 law.cstr <- function(law.index, law.pars = NULL) {
 
-    if(getRversion() < "3.1.0") dontCheck <- identity
 
 # We get the default (maximal) number of parameters and the default values of the parameters
 # We use the trick to put the first element of *name to "1" to also retrieve the default values
-    Claw.name <- paste("law", law.index, sep = "")
-    out <- .C(dontCheck(Claw.name), 0L, 0.0, name = c("1", rep(" ", 49)), 1L, params = rep(0.0, 4), nbparams = 0L, 0L, PACKAGE = "PoweR")
+  Claw.name <- paste("law", law.index, sep = "")
+  #lawsym <- getNativeSymbolInfo(Claw.name, PACKAGE = "PoweR")
+mydotC <- get(".PoweR_law_dispatch", envir = asNamespace("PoweR"))[[Claw.name]]; if (is.null(mydotC)) stop("Unknown law function: ", Claw.name)
+
+    out <- #.C(lawsym, 
+    mydotC(0L, 0.0, name = c("1", rep(" ", 49)), 1L, params = rep(0.0, 4), nbparams = 0L, 0L, PACKAGE = "PoweR")
     nbparams <- out$nbparams
     if (length(law.pars) > nbparams) stop(paste("Length of 'law.pars' should be at most", nbparams))
     if (length(law.pars) >= 1) law.pars <- c(law.pars, out$params[-(1:length(law.pars))])[1:nbparams]
