@@ -47,12 +47,12 @@ extern "C" {
       a = params[0];
       b = params[1];
     } else {
-      error("Number of parameters should be at most: 2");
+      Rf_error("Number of parameters should be at most: 2");
     }
 
 // If necessary, we check if some parameter values are out of parameter space
     if (a > b) {
-      warning("a should not be > b in law32!\n");
+      Rf_warning("a should not be > b in law32!\n");
       for (i = 0; i < n; i++) x[i] = R_NaN;
       return;
     }
